.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`viewer.plugins`
=============================
.. automodule:: skimage.viewer.plugins

.. currentmodule:: skimage.viewer.plugins
.. autosummary::


   skimage.viewer.plugins.CannyPlugin
   skimage.viewer.plugins.ColorHistogram
   skimage.viewer.plugins.Crop
   skimage.viewer.plugins.LabelPainter
   skimage.viewer.plugins.LineProfile
   skimage.viewer.plugins.Measure
   skimage.viewer.plugins.OverlayPlugin
   skimage.viewer.plugins.PlotPlugin
   skimage.viewer.plugins.Plugin

    skimage.viewer.plugins.base
    skimage.viewer.plugins.canny
    skimage.viewer.plugins.color_histogram
    skimage.viewer.plugins.crop
    skimage.viewer.plugins.labelplugin
    skimage.viewer.plugins.lineprofile
    skimage.viewer.plugins.measure
    skimage.viewer.plugins.overlayplugin
    skimage.viewer.plugins.plotplugin


:class:`CannyPlugin`
--------------------


.. autoclass:: CannyPlugin
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.plugins.CannyPlugin.examples


:class:`ColorHistogram`
-----------------------


.. autoclass:: ColorHistogram
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.plugins.ColorHistogram.examples


:class:`Crop`
-------------


.. autoclass:: Crop
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.plugins.Crop.examples


:class:`LabelPainter`
---------------------


.. autoclass:: LabelPainter
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.plugins.LabelPainter.examples


:class:`LineProfile`
--------------------


.. autoclass:: LineProfile
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.plugins.LineProfile.examples


:class:`Measure`
----------------


.. autoclass:: Measure
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.plugins.Measure.examples


:class:`OverlayPlugin`
----------------------


.. autoclass:: OverlayPlugin
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.plugins.OverlayPlugin.examples


:class:`PlotPlugin`
-------------------


.. autoclass:: PlotPlugin
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.plugins.PlotPlugin.examples


:class:`Plugin`
---------------


.. autoclass:: Plugin
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.plugins.Plugin.examples

